import java.io.*;
import java.net.*;
import java.util.*;


class  NetTestComServer
{
    private SysProp	  sys_prop;
    private Param	  param;
    private LogOut	  log_out;
    private ServerSocket  server_socket;


    NetTestComServer (SysProp  sys_prop,
		      Param    param)
    {
	this.sys_prop	   = sys_prop;
	this.param	   = param;
	this.log_out	   = new LogOut	(param);
	this.server_socket = null;
    }


    private void  run ()
    {
	int  port = param.getPort ();

	try
	{
	    server_socket = new ServerSocket (port);

	    handleIncoming ();
	}
	catch (IOException  io_except)
	{
	    System.err.println (Param.JAVA_NAME + ": " +
				io_except.getMessage () +
				": Server socket at port: " + port);
	    System.exit	       (1);
	}
	finally
	{
	    if (server_socket != null)
	    {
		try
		{
		    server_socket.close ();
		}
		catch (IOException  io_close_except)
		{
		    System.err.println (Param.JAVA_NAME + ": " +
					io_close_except.getMessage () +
					": Close server socket at " +
					"port: " + port);
		    System.exit        (1);
		}
	    }
	}
    }


    private void  handleIncoming ()
    {
	boolean  use_log_file = param.useLogFile ();
	int	 root_id      = 0;
	int	 request_id   = root_id;

	String  date = Calendar.getInstance ().getTime ().toString ();
	int	port = param.getPort ();

	log_out.printLine (date + ":", request_id);
	log_out.printLine ("     Listening on port " + port,
			   request_id);

	for (;;)
	{
	    try
	    {
		Socket  client_socket = server_socket.accept ();

		if (request_id < Integer.MAX_VALUE)
		    request_id++;
		else
		    request_id = 1;

		NetTestCommand  net_test_com = new NetTestCommand (
						       client_socket,
						       sys_prop,
						       param,
						       log_out,
						       request_id);

		net_test_com.start ();
	    }
	    catch (IOException  io_except)
	    {
		log_out.printLine (io_except.getMessage (), root_id);
	    }
	}
    }


    public static void  main (String []  argv)
    {
	SysProp  sys_prop = new SysProp (	 );
	Param	 param	  = new Param	(sys_prop);

	param.parseArguments (argv);

	NetTestComServer  net_test_com_server = new NetTestComServer (
							sys_prop,
							param);

	net_test_com_server.run ();
    }
}
