/* ------------------------------------------------------------------ */
/*		   D a t e V a r T a b l e . j a v a		      */
/*		   =================================		      */
/*								      */
/*   This file contains the source of the "DateVarTable" class.       */
/* ------------------------------------------------------------------ */


import java.util.*;


/**
 * This class is used to parse the date variables and to store them in
 * a <CODE>Vector</CODE>.
 *
 *    @author  Hans Blom
 *
******************/
class  DateVarTable
/*****************/
{
    /*
     * Define the class constants.
     */

    private static final int  NR_INPUT_FIELDS = 2; // # Fields / inp. l.
    private static final int  DATE_IND	      = 0; // Index weet date.
    private static final int  ID_IND	      = 1; // Index week ID.

    /*
     * Define the class variables.
     */
     
    private Vector   date_vars;	      // The vector with the date data.
    private int	     nr_lines_parsed; // The # lines parsed with date d.
    private boolean  show_current;    // Flag to show the current date.


    /**
     * Constructor.
     *
     *    @param  show_current   Show the current date when true; do not
     *				 show it otherwise.
     *
    ***********************************/
    DateVarTable (boolean  show_current)
    /**********************************/
    {
	/*
	 * Initialise the variables.
	 */

	this.date_vars	     = new Vector ();
	this.nr_lines_parsed = 0;
	this.show_current    = show_current;
    }


    /**
     * Clear the vector with the date variables by emptying the
     * storage.
     *
    *************/
    void  clear ()
    /************/
    {
	date_vars.removeAllElements ();
	nr_lines_parsed = 0;
    }


    /**
     * Parse the specified input line and store the date parameters read
     * in the date variables vector. The current date is also shown when
     * selected by the corresponding flag.
     *
     *    @param  input_line   The input line to parse.
     *
     *    @exception  Exception   An exception is thrown after a bad
     *				  formatted input line.
     *
    *************************************************************/
    void  parseLine (CharInputLine  input_line)  throws  Exception
    /************************************************************/
    {
	/*
	 * Split the input line into a new allocated string array. The
	 * array, containing the date variables, is added to the vector
	 * with all date variables. It is assumed that the dates are
	 * sorted to increasing history. The current date (the first
	 * line read) is also shown when selected.
	 */

	if (show_current  ||  !show_current  &&  nr_lines_parsed > 0)
	{
	    /*
	     * Allocate storage for the date variables.
	     */
	     
	    String []  input_words = new String [NR_INPUT_FIELDS];

	    /*
	     * Split the input line according to space characters.
	     */

	    StringTools.split (input_words,
			       StringTools.SPACE_SEPARS,
			       input_line.getArray  (),
			       input_line.getOffset (),
			       input_line.getBound  ());

	    /*
	     * Add the date variables to the end of the vector.
	     */
	     
	    date_vars.addElement (input_words);

	} // An input line is parsed.

	nr_lines_parsed++;

    } // parseLine ()


    /**
     * Get the size of the date variables vector.
     *
     *    @return  The vector size.
     *
    ***********/
    int  size ()
    /**********/
    {
	return date_vars.size ();
    }


    /**
     * Return the date of the first day of the date interval at the
     * specified index of the date vector.
     *
     *    @param  index   The index of the date in the vector.
     *
     *    @return  The date of the first day in the date.
     *
    ***************************/
    String  getDate (int  index)
    /**************************/
    {
	String []  date_var = (String []) date_vars.elementAt (index);

	return date_var [DATE_IND];
    }


    /**
     * Return the ID of the date at the specified index of the date
     * vector.
     *
     *    @param  index   The index of the date in the vector.
     *
     *    @return  The date&nbsp;ID.
     *
    *************************/
    String  getID (int  index)
    /************************/
    {
	String []  date_var = (String []) date_vars.elementAt (index);

	return date_var [ID_IND];
    }

} // class DateVarTable
