/* ------------------------------------------------------------------ */
/*	       P l o t L e g e n d H a n d l e r. j a v a	      */
/*	       ==========================================	      */
/*								      */
/*   This file contains the source of the "PlotLegendHandler"	      */
/*   interface.							      */
/* ------------------------------------------------------------------ */


import java.awt.*;
import user.plot.*;


/**
 * This interface is used by the <CODE>LegendCanvas</CODE> class to
 * handle the corresponding plot or to obtain information from it.
 *
 *    @author  Hans Blom
 *
***************************/
interface  PlotLegendHandler
/**************************/
{
    /**
     * Return the background color of the specified legend.
     *
     *    @param  index   The index of the legend to specify.
     *
     *    @return   The legend background color.
     *
    **********************************************/
    public Color  getLegendBackground (int  index);
    /*********************************************/


    /**
     * Return the foreground color of the specified legend.
     *
     *    @param  index   The index of the legend to specify.
     *
     *    @return   The legend foreground color.
     *
    **********************************************/
    public Color  getLegendForeground (int  index);
    /*********************************************/


    /**
     * Return if markers should be used in the legends.
     *
     *    @return   True when markers should be used; false otherwise.
     *
    **************************************/
    public boolean  getLegendUseMarkers ();
    /*************************************/


    /**
     * Get the marker used in the specified legend.
     *
     *    @param  index   The index of the legend to specify.
     *
     *    @return   The marker of the specify legend.
     *
    ***************************************************/
    public PlotMarker  getLegendPlotMarker (int  index);
    /**************************************************/


    /**
     * This function is called when the mouse enters the legend canvas.
     *
    ********************************/
    public void  legendMouseEnter ();
    /*******************************/


    /**
     * This function is called when the mouse exits the legend canvas.
     *
    *******************************/
    public void  legendMouseExit ();
    /******************************/


    /**
     * This function is called when the mouse is released in a legend
     * box. The mouse up event and The index of the legend box where the
     * mouse is relased are specified. If the mouse is not in a legend
     * box, the legend index is set to&nbsp;-1. There should be returned
     * if the action has been used.
     *
     *    @param  event   The mouse up event.
     *
     *    @param  index   The index of the legend where the mouse is
     *			  released.
     *
     *    @return   True when the action has been handled; false
     *		    otherwise.
     *
    ***************************************************/
    public boolean  legendMouseUp (Event  event,
				   int	  legend_index);
    /**************************************************/

} // interface PlotLegendHandler
